diff ui/certificatelist.cpp @ 31:37fc66967517

Implement signature verification wiht polarssl
author Andre Heinecke <aheinecke@intevation.de>
date Thu, 13 Mar 2014 18:12:16 +0000
parents dc1e1e9e62ce
children 64c8c6350e60
line wrap: on
line diff
--- a/ui/certificatelist.cpp	Thu Mar 13 17:26:33 2014 +0000
+++ b/ui/certificatelist.cpp	Thu Mar 13 18:12:16 2014 +0000
@@ -9,7 +9,7 @@
     char *data = NULL;
     size_t size = 0;
 
-    mStatus = readAndVerifyList(fileName, &data, &size);
+    mStatus = read_and_verify_list(fileName, &data, &size);
 
     if (!isValid()) {
         return;
@@ -49,7 +49,7 @@
             mCertificatesInstall << Certificate(
                     QByteArray::fromBase64(curLine.remove(0,2).toLatin1()));
         } else if (curLine.startsWith("S:")) {
             // Signature is verified in readAndVerifyList
             continue;
         } else if (!curLine.isEmpty()){
             qDebug () << "Don't know how to handle: " << curLine;
@@ -49,7 +49,7 @@
                     QByteArray::fromBase64(curLine.remove(0,2).toLatin1()));
         } else if (curLine.startsWith("S:")) {
-            // Signature is verified in readAndVerifyList
+            // Signature is verified in read_and_verify_list
             continue;
         } else if (!curLine.isEmpty()){

http://wald.intevation.org/projects/trustbridge/